==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/waf/kotlin/RegexPatternSet.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [RegexPatternSet].
 */
@PulumiTagMarker
public class RegexPatternSetResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RegexPatternSetArgs = RegexPatternSetArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RegexPatternSetArgsBuilder.() -> Unit) {
        val builder = RegexPatternSetArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): RegexPatternSet {
        val builtJavaResource = com.pulumi.aws.waf.RegexPatternSet(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return RegexPatternSet(builtJavaResource)
    }
}

/**
 * Provides a WAF Regex Pattern Set Resource
 * ## Example Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.waf.RegexPatternSet;
 * import com.pulumi.aws.waf.RegexPatternSetArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new RegexPatternSet("example", RegexPatternSetArgs.builder()
 *             .regexPatternStrings(
 *                 "one",
 *                 "two")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import AWS WAF Regex Pattern Set using their ID. For example:
 * ```sh
 *  $ pulumi import aws:waf/regexPatternSet:RegexPatternSet example a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
 * ```
 *
 */
public class RegexPatternSet internal constructor(
    override val javaResource: com.pulumi.aws.waf.RegexPatternSet,
) : KotlinCustomResource(javaResource, RegexPatternSetMapper) {
    /**
     * Amazon Resource Name (ARN)
     */
    public val arn: Output<String>
        get() = javaResource.arn().applyValue({ args0 -> args0 })

    /**
     * The name or description of the Regex Pattern Set.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * A list of regular expression (regex) patterns that you want AWS WAF to search for, such as `B[a@]dB[o0]t`.
     */
    public val regexPatternStrings: Output<List<String>>?
        get() = javaResource.regexPatternStrings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })
}

public object RegexPatternSetMapper : ResourceMapper<RegexPatternSet> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.waf.RegexPatternSet::class == javaResource::class

    override fun map(javaResource: Resource): RegexPatternSet = RegexPatternSet(
        javaResource as
            com.pulumi.aws.waf.RegexPatternSet,
    )
}

/**
 * @see [RegexPatternSet].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RegexPatternSet].
 */
public suspend fun regexPatternSet(
    name: String,
    block: suspend RegexPatternSetResourceBuilder.() -> Unit,
): RegexPatternSet {
    val builder = RegexPatternSetResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RegexPatternSet].
 * @param name The _unique_ name of the resulting resource.
 */
public fun regexPatternSet(name: String): RegexPatternSet {
    val builder = RegexPatternSetResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/waf/kotlin/RegexPatternSet.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [RegexPatternSet].
 */
@PulumiTagMarker
public class RegexPatternSetResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RegexPatternSetArgs = RegexPatternSetArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RegexPatternSetArgsBuilder.() -> Unit) {
        val builder = RegexPatternSetArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): RegexPatternSet {
        val builtJavaResource = com.pulumi.aws.waf.RegexPatternSet(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return RegexPatternSet(builtJavaResource)
    }
}

/**
 * Provides a WAF Regex Pattern Set Resource
 * ## Example Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.waf.RegexPatternSet("example", {
 *     name: "my_waf_regex_pattern_set",
 *     regexPatternStrings: [
 *         "one",
 *         "two",
 *     ],
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.waf.RegexPatternSet("example",
 *     name="my_waf_regex_pattern_set",
 *     regex_pattern_strings=[
 *         "one",
 *         "two",
 *     ])
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Waf.RegexPatternSet("example", new()
 *     {
 *         Name = "my_waf_regex_pattern_set",
 *         RegexPatternStrings = new[]
 *         {
 *             "one",
 *             "two",
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/waf"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := waf.NewRegexPatternSet(ctx, "example", &waf.RegexPatternSetArgs{
 * 			Name: pulumi.String("my_waf_regex_pattern_set"),
 * 			RegexPatternStrings: pulumi.StringArray{
 * 				pulumi.String("one"),
 * 				pulumi.String("two"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.waf.RegexPatternSet;
 * import com.pulumi.aws.waf.RegexPatternSetArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new RegexPatternSet("example", RegexPatternSetArgs.builder()
 *             .name("my_waf_regex_pattern_set")
 *             .regexPatternStrings(
 *                 "one",
 *                 "two")
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:waf:RegexPatternSet
 *     properties:
 *       name: my_waf_regex_pattern_set
 *       regexPatternStrings:
 *         - one
 *         - two
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import AWS WAF Regex Pattern Set using their ID. For example:
 * ```sh
 * $ pulumi import aws:waf/regexPatternSet:RegexPatternSet example a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
 * ```
 */
public class RegexPatternSet internal constructor(
    override val javaResource: com.pulumi.aws.waf.RegexPatternSet,
) : KotlinCustomResource(javaResource, RegexPatternSetMapper) {
    /**
     * Amazon Resource Name (ARN)
     */
    public val arn: Output<String>
        get() = javaResource.arn().applyValue({ args0 -> args0 })

    /**
     * The name or description of the Regex Pattern Set.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * A list of regular expression (regex) patterns that you want AWS WAF to search for, such as `B[a@]dB[o0]t`.
     */
    public val regexPatternStrings: Output<List<String>>?
        get() = javaResource.regexPatternStrings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })
}

public object RegexPatternSetMapper : ResourceMapper<RegexPatternSet> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.waf.RegexPatternSet::class == javaResource::class

    override fun map(javaResource: Resource): RegexPatternSet = RegexPatternSet(
        javaResource as
            com.pulumi.aws.waf.RegexPatternSet,
    )
}

/**
 * @see [RegexPatternSet].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RegexPatternSet].
 */
public suspend fun regexPatternSet(
    name: String,
    block: suspend RegexPatternSetResourceBuilder.() -> Unit,
): RegexPatternSet {
    val builder = RegexPatternSetResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RegexPatternSet].
 * @param name The _unique_ name of the resulting resource.
 */
public fun regexPatternSet(name: String): RegexPatternSet {
    val builder = RegexPatternSetResourceBuilder()
    builder.name(name)
    return builder.build()
}
